@@ -96,9 +96,6 @@ class DistributeStatus(object):
     # 虚拟已确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
 
-    # 2022.09 特需售后单自提转快递支付运费订单的发货单
-    MAKEUP_POSTAGE_PAID = "paid"
-
     NO_SPLIT_STATUS_LIST = [
         INIT,
         HGVENDING_INIT,
@@ -129,7 +126,6 @@ class DistributeStatus(object):
         HAITAO_PACKAGED,
         HAITAO_RETURN,
         SERVICE_STOP,
-        MAKEUP_POSTAGE_PAID,
     ]
     
 
@@ -149,7 +145,6 @@ class DistributeStatus(object):
         OUTSTORAGE_WAIT_PACKAGE,
         OUTSTORAGE_PACKAGED,
         SERVICE_STOP,
-        MAKEUP_POSTAGE_PAID,
     ]
 
     ## 初始态集合
@@ -167,9 +162,7 @@ class DistributeStatus(object):
         PRINTED,
         GUIDE_PICKED_UP,
         SPLIT,
-        HGVENDING_WAIT_PICKUP,
-        # 补缴运费的商品可以整单退
-        MAKEUP_POSTAGE_PAID,
+        HGVENDING_WAIT_PICKUP
     ]
 
     BEFORE_cuservice_pick_up = [
@@ -222,7 +215,6 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: "已发货",
         HAITAO_RETURN: "售后",
         SERVICE_STOP: "待发货",
-        MAKEUP_POSTAGE_PAID: "运费已支付",
     }
     # For B端 查询
     DISTRIBUTE_STATUS_CHOICES_FOR_B_QUERY = {
@@ -254,8 +246,7 @@ class DistributeStatus(object):
         HAITAO_BAISHI: "海淘已推百世",
         HAITAO_PACKAGED: "海淘已发货",
         HAITAO_RETURN: "海淘已退",
-        SERVICE_STOP: "滞留仓已收",
-        MAKEUP_POSTAGE_PAID: "运费已支付",
+        SERVICE_STOP: "滞留仓已收"
     }
 
     DISTRIBUTE_MESSAGE_DICT_FOR_C = {
@@ -283,7 +274,6 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: "海淘已发货。",
         HAITAO_RETURN: "海淘已售后。",
         SERVICE_STOP: "暂时无法发货，商品滞留。",
-        MAKEUP_POSTAGE_PAID: "订单自提转快递运费已支付。",
     }
 
     DISTRIBUTE_STATUS_CHOICES = (
@@ -317,7 +307,6 @@ class DistributeStatus(object):
         (SERVICE_STOP, "滞留仓已收"),
         (VIRTUAL_INIT, "虚拟商品初始态"),
         (CUS_CONFIRM_AT_VIRTUAL, "虚拟商品已提货"),
-        (MAKEUP_POSTAGE_PAID, "运费已支付"),
     )
 
     DISTRIBUTE_STATUS_OWNER_DICT = {
@@ -350,7 +339,6 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: DistributeStatusOwner.HAITAO,
         HAITAO_RETURN: DistributeStatusOwner.HAITAO,
         SERVICE_STOP: DistributeStatusOwner.CUSSERVICE,
-        MAKEUP_POSTAGE_PAID: DistributeStatusOwner.CUSTOMER,
     }
 
     DISTRIBUTE_STATUS_DIRECTION_DICT = {
@@ -382,8 +370,6 @@ class DistributeStatus(object):
         HAITAO_PACKAGED: DistributeDirection.HAITAO,
         HAITAO_RETURN: DistributeDirection.HAITAO,
         SERVICE_STOP: DistributeDirection.CUSSERVICE,
-
-        MAKEUP_POSTAGE_PAID: DistributeDirection.CUSSERVICE,
     }
 
     # 终结状态列表
@@ -406,8 +392,7 @@ class DistributeStatus(object):
         TAILPAY_OVERTIME,
         # 海淘
         HAITAO_PACKAGED,
-        HAITAO_RETURN,
-        MAKEUP_POSTAGE_PAID,
+        HAITAO_RETURN
     ]
 
     # 非最终状态
@@ -440,16 +425,6 @@ class DistributeStatus(object):
         CUS_CONFIRM_AT_CUSSERVICE,
     ]
 
-    # 未售后的不支持修改配送方式的发货单状态
-    CAN_NOT_MODY_SHIPPING_METHOD_DISTRIBUTE_STATUS_LIST = [
-        CUS_CONFIRM_AT_GUIDE,
-        CUS_CONFIRM_AT_CUSSERVICE,
-        PACKAGED,
-        OUTSTORAGE_PACKAGED,
-        OUTSTORAGE_WAIT_PACKAGE,
-        SPLIT,
-    ]
-
 
 class ShippingMethod(object):
     # 普通快递
@@ -567,8 +542,6 @@ class DistributeEventConst(object):
     AFSPLUS_OPEN = "afsplus_open"
     AFSPLUS_CLOSE = "afsplus_close"
     AFSPLUS_COMPLETE = "afsplus_complete"
-    AFSPLUS_S2E = "afsplus_s2e"  # 自提转快递
-    AFSPLUS_E2S = "afsplus_e2s"  # 快递转自提
 
     # 2022.08 虚拟商品确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
@@ -717,7 +690,6 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
-                DistributeStatus.MAKEUP_POSTAGE_PAID,
             ],
 
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
@@ -741,9 +713,8 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.DEPOSITPAY: None,
                 DistributeStatus.SERVICE_STOP: DistributeStatus.SPLIT,
-                # DistributeStatus.HAITAO_INIT: None,
+            #    DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.TAILPAY_OVERTIME: None,
-                DistributeStatus.MAKEUP_POSTAGE_PAID: None,
             },
         },
         CLOSE_AFTERSALE: {
@@ -761,7 +732,6 @@ class DistributeEventConst(object):
                 DistributeStatus.SERVICE_STOP,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
-                DistributeStatus.MAKEUP_POSTAGE_PAID,
                 ],
             DistributeEventConstKey.TO_STATUS_KEY: None,
         },
@@ -777,7 +747,6 @@ class DistributeEventConst(object):
                 DistributeStatus.HAITAO_INIT,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
-                DistributeStatus.MAKEUP_POSTAGE_PAID,
                 ],
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
                 DistributeStatus.INIT: DistributeStatus.NO_PICKUP_RETURN,
@@ -793,7 +762,6 @@ class DistributeEventConst(object):
                 DistributeStatus.DEPOSITPAY: DistributeStatus.DEPOSITPAY_RETURN,
                 DistributeStatus.TAILPAY_OVERTIME: DistributeStatus.DEPOSITPAY_RETURN,
                 DistributeStatus.CUS_CONFIRM_AT_VIRTUAL: None,
-                DistributeStatus.MAKEUP_POSTAGE_PAID: None,
             }
         },
         CREATE_EXPRESS: {
@@ -963,29 +931,6 @@ class DistributeEventConst(object):
             ],
             DistributeEventConstKey.TO_STATUS_KEY: None
         },
-        AFSPLUS_S2E: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
-                DistributeStatus.INIT, DistributeStatus.PRINTED,
-                                DistributeStatus.CUSSERVICE_PICKED_UP,
-                                DistributeStatus.GUIDE_PICKED_UP,
-                                DistributeStatus.SERVICE_DESK,
-                                DistributeStatus.SERVICE_STORE,
-                                DistributeStatus.SERVICE_STOP,
-            ],
-            DistributeEventConstKey.TO_STATUS_KEY: None
-        },
-        AFSPLUS_E2S: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
-                DistributeStatus.INIT, DistributeStatus.PRINTED,
-                                DistributeStatus.CUSSERVICE_PICKED_UP,
-                                DistributeStatus.GUIDE_PICKED_UP,
-                                DistributeStatus.SERVICE_DESK,
-                                DistributeStatus.SERVICE_STORE,
-                                DistributeStatus.SERVICE_STOP,
-            ],
-            DistributeEventConstKey.TO_STATUS_KEY: None
-        },
-
         # 2022.08 虚拟商品确收事件
         CUS_CONFIRM_AT_VIRTUAL: {
             DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
@@ -1072,8 +1017,6 @@ class DistributeEventConst(object):
         AFSPLUS_OPEN: "申请特殊售后",
         AFSPLUS_CLOSE: "取消特殊售后",
         AFSPLUS_COMPLETE: "完成特殊售后",
-        AFSPLUS_S2E: "自提转快递",  # 自提转快递
-        AFSPLUS_E2S: "快递转自提",  # 快递转自提
 
         # 虚拟商品
         CUS_CONFIRM_AT_VIRTUAL: "虚拟商品确收"
@@ -1176,20 +1119,22 @@ OLAY_SHOP_DICT_CONST = {
 
 class AddressGroupStatus(object):
     """
-    可合-已齐、可合-未齐、无可合、已合单、单单、其他
+    可合-已齐、可合-未齐、无可合、已合单、在库已合、单单、无在库、其他
     """
-    # 可合-已齐
+    # 可合-已齐（多单在库、未合、无其他状态）
     MERGABLE_READY = "mergable_ready"
-    # 可合-未齐
+    # 可合-未齐（多单在库、未合、有其他状态）
     MERGABLE_WAITING = "mergable_waiting"
-    # 已合单
+    # 已合单（多单在库、已合、无其他状态）
     MERGED = "merged"
-    # 在库-已合
+    # 在库-已合（多单在库、已合、有其他状态）
     MERGED_IN_STORE = "merged_in_store"
-    # 无可合
+    # 无可合（一单在库、有其他状态）
     UNMERGABLE = "unmergable"
-    # 单单
+    # 单单（一单在库、无其他状态）
     SINGLE = 'single'
+    # 无在库（0单在库、有其他状态）
+    NO_IN_STORE = 'no_in_store'
     # 其他
     OTHER = 'other'
 
@@ -1200,10 +1145,11 @@ class AddressGroupStatus(object):
         (MERGED_IN_STORE, "在库-已合"),
         (UNMERGABLE, "无可合"),
         (SINGLE, "单单"),
+        (NO_IN_STORE, "无在库"),
         (OTHER, "其他"),
     )
     # 存在未终结发货单的分组
-    UNTERMINATE_STATUS_LIST = [MERGABLE_READY,MERGABLE_WAITING, MERGED, UNMERGABLE, SINGLE]
+    UNTERMINATE_STATUS_LIST = [MERGABLE_READY, MERGABLE_WAITING, MERGED, MERGED_IN_STORE, UNMERGABLE, NO_IN_STORE, SINGLE]
 
 """
 发货单运送变更事件 枚举
